@@ -517,7 +517,7 @@ class StreamResponse(HeadersMixin):
         if value is None:
             self._content_dict.pop('charset', None)
         else:
-            self._content_dict['charset'] = str(value)
+            self._content_dict['charset'] = str(value).lower()
         self._generate_content_type_header()
 
     def _generate_content_type_header(self):
@@ -1044,7 +1044,9 @@ class StaticRoute(Route):
 
 class UrlDispatcher(AbstractRouter, collections.abc.Mapping):
 
-    DYN = re.compile(r'^\{[a-zA-Z][_a-zA-Z0-9]*\}$')
+    DYN = re.compile(r'^\{(?P<var>[a-zA-Z][_a-zA-Z0-9]*)\}$')
+    DYN_WITH_RE = re.compile(
+        r'^\{(?P<var>[a-zA-Z][_a-zA-Z0-9]*):(?P<re>.+)\}$')
     GOOD = r'[^{}/]+'
     PLAIN = re.compile('^' + GOOD + '$')
 
@@ -1110,20 +1112,34 @@ class UrlDispatcher(AbstractRouter, collections.abc.Mapping):
         for part in path.split('/'):
             if not part:
                 continue
-            if self.DYN.match(part):
-                parts.append('(?P<' + part[1:-1] + '>' + self.GOOD + ')')
+            match = self.DYN.match(part)
+            if match:
+                parts.append('(?P<' + match.group('var') + '>' +
+                             self.GOOD + ')')
                 factory = DynamicRoute
-            elif self.PLAIN.match(part):
+                continue
+
+            match = self.DYN_WITH_RE.match(part)
+            if match:
+                parts.append('(?P<' + match.group('var') + '>' +
+                             match.group('re') + ')')
+                factory = DynamicRoute
+                continue
+            if self.PLAIN.match(part):
                 parts.append(re.escape(part))
-            else:
-                raise ValueError("Invalid path '{}'['{}']".format(path, part))
+                continue
+            raise ValueError("Invalid path '{}'['{}']".format(path, part))
         if factory is PlainRoute:
             route = PlainRoute(method, handler, name, path)
         else:
             pattern = '/' + '/'.join(parts)
             if path.endswith('/') and pattern != '/':
                 pattern += '/'
-            compiled = re.compile('^' + pattern + '$')
+            try:
+                compiled = re.compile('^' + pattern + '$')
+            except re.error as exc:
+                raise ValueError(
+                    "Bad pattern '{}': {}".format(pattern, exc)) from None
             route = DynamicRoute(method, handler, name, compiled, path)
         self._register_endpoint(route)
         return route
@@ -1157,6 +1173,7 @@ class RequestHandler(ServerHttpProtocol):
         self._manager = manager
         self._app = app
         self._router = router
+        self._middlewares = app.middlewares
 
     def connection_made(self, transport):
         super().connection_made(transport)
@@ -1172,7 +1189,8 @@ class RequestHandler(ServerHttpProtocol):
     def handle_request(self, message, payload):
         now = self._loop.time()
 
-        request = Request(self._app, message, payload,
+        app = self._app
+        request = Request(app, message, payload,
                           self.transport, self.writer, self.keep_alive_timeout)
         try:
             match_info = yield from self._router.resolve(request)
@@ -1182,7 +1200,10 @@ class RequestHandler(ServerHttpProtocol):
             request._match_info = match_info
             handler = match_info.handler
 
+            for factory in reversed(self._middlewares):
+                handler = yield from factory(app, handler)
             resp = yield from handler(request)
+
             if not isinstance(resp, StreamResponse):
                 raise RuntimeError(
                     ("Handler should return response instance, got {!r}")
@@ -1257,8 +1278,8 @@ class RequestHandlerFactory:
 class Application(dict):
 
     def __init__(self, *, logger=web_logger, loop=None,
-                 router=None, handler_factory=RequestHandlerFactory, **kwargs):
-        # TODO: explicitly accept *debug* param
+                 router=None, handler_factory=RequestHandlerFactory,
+                 middlewares=(), **kwargs):
         if loop is None:
             loop = asyncio.get_event_loop()
         if router is None:
@@ -1272,6 +1293,9 @@ class Application(dict):
         self.logger = logger
 
         self.update(**kwargs)
+        for factory in middlewares:
+            assert asyncio.iscoroutinefunction(factory), factory
+        self._middlewares = tuple(middlewares)
 
     @property
     def router(self):
@@ -1281,6 +1305,10 @@ class Application(dict):
     def loop(self):
         return self._loop
 
+    @property
+    def middlewares(self):
+        return self._middlewares
+
     def make_handler(self, **kwargs):
         return self._handler_factory(
             self, self.router, loop=self.loop, **kwargs)
