@@ -17,7 +17,7 @@ import time
 from urllib.parse import urlsplit
 
 import aiohttp
-from aiohttp import server
+from aiohttp import server, helpers
 
 
 class WSGIServerHttpProtocol(server.ServerHttpProtocol):
@@ -89,32 +89,9 @@ class WSGIServerHttpProtocol(server.ServerHttpProtocol):
 
             environ[key] = hdr_value
 
-        if isinstance(forward, str):
-            # we only took the last one
-            # http://en.wikipedia.org/wiki/X-Forwarded-For
-            if ',' in forward:
-                forward = forward.rsplit(',', 1)[-1].strip()
-
-            # find host and port on ipv6 address
-            if '[' in forward and ']' in forward:
-                host = forward.split(']')[0][1:].lower()
-            elif ':' in forward and forward.count(':') == 1:
-                host = forward.split(':')[0].lower()
-            else:
-                host = forward
-
-            forward = forward.split(']')[-1]
-            if ':' in forward and forward.count(':') == 1:
-                port = forward.split(':', 1)[1]
-            else:
-                port = 80
-
-            remote = (host, port)
-        else:
-            remote = forward
-
+        remote = helpers.parse_remote_addr(forward)
         environ['REMOTE_ADDR'] = remote[0]
-        environ['REMOTE_PORT'] = str(remote[1])
+        environ['REMOTE_PORT'] = remote[1]
 
         if isinstance(server, str):
             server = server.split(':')
